@@ -1,3 +1,3 @@
 from DrcomExecutor.config.config import config, Config
 
-all = ['config', 'Config']
+all = ["config", "Config"]
